pyramid_versionbadge
====================

Minimal tween to display a version number or other stuff on
every page of your app.

<div id="versionbadge">Your text</div>

To use, include the tween and set a value for "versionbadge.text"
in your config registry. You can also set a value for "versionbadge.css"
to have the div get a css class.

If the text value is empty, the div will not be rendered.

If the text value is not included in the config at all, it will be
rendered with a default value.
